Sentiment Analysis
===================

.. note::

    This tutorial is available as an IPython notebook
    `here <https://github.com/huseinzol05/Malaya/tree/master/example/sentiment>`_.

.. include:: load-sentiment.rst
